@@ -2,35 +2,28 @@ use strict;
 use warnings;
 
 package Test::Deep::Ref;
+use Carp qw( confess );
 
 use Test::Deep::Cmp;
 
+use vars qw( @ISA );
+@ISA = qw( Test::Deep::Cmp );
+
 use Scalar::Util qw( blessed );
 
 sub test_class
 {
 	my $self = shift;
-	my $got = shift;
+	my $d1 = shift;
 
 	my $exp = $self->{val};
 	
 	if ($Test::Deep::Snobby)
 	{
-		return Test::Deep::descend($got, Test::Deep::blessed(blessed($exp)));
+		return 0 unless Test::Deep::blessed(blessed($exp))->descend($d1);
 	}
-	else
-	{
-		return 1;
-	}
-}
 
-sub test_reftype
-{
-	my $self = shift;
-	my $got = shift;
-	my $reftype = shift;
-
-	return Test::Deep::descend($got, Test::Deep::reftype($reftype));
+	return 1;
 }
 
 1;
