@@ -1,4 +1,5 @@
 use strict;
+use warnings;
 
 package Test::Deep::Regexp;
 use Carp qw( confess );
@@ -30,8 +31,6 @@ sub descend
 
 	push(@Test::Deep::Stack, \%data);
 
-	local $Test::Deep::Shallow = 1;
-
 	my $ok = ($d1 =~ $self->{val}) ? 1 : 0;
 
 	pop @Test::Deep::Stack if $ok;
